==> haskell-equivalence-0.3.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.5
id: equivalence-0.3.5-HHQiyUBROHbLGg9TubwXhw
key: equivalence-0.3.5-HHQiyUBROHbLGg9TubwXhw
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: e47a8a16a4bc220496f45bed48a1db0f
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/equivalence-0.3.5
hs-libraries: HSequivalence-0.3.5-HHQiyUBROHbLGg9TubwXhw
depends:
    STMonadTrans-0.4.4-3sgM05tr5JY7kOuWWImpx3 base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.5
id: equivalence-0.3.5-Iur2kYHEMmeAlLZHP2eOt3
key: equivalence-0.3.5-Iur2kYHEMmeAlLZHP2eOt3
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: 643f301f9821e03aa5f80c2ce16a2a66
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/equivalence-0.3.5
hs-libraries: HSequivalence-0.3.5-Iur2kYHEMmeAlLZHP2eOt3
depends:
    STMonadTrans-0.4.4-2qTBg07wvhm457iXZaqR4r base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
